@@ -18,7 +18,8 @@ async def findLinksAsync(source):
     return posts
 
 def findLinks(source):
-    loop = asyncio.get_event_loop()
+    loop = asyncio.new_event_loop()
+    asyncio.set_event_loop(loop)
     r = loop.run_until_complete(findLinksAsync(source))
     links = {}
     for message in r.messages:
